package SPVM::File::Temp;

our $VERSION = '0.01';

1;

=head1 Name

SPVM::File::Temp - Short Description

=head1 Description

C<SPVM::File::Temp> is the C<File::Temp> class in L<SPVM> language.

=head1 Usage

  use File::Temp;

=head1 Fields



=head1 Class Methods



=head1 Instance Methods



=head1 Repository



=head1 Author

Yuki Kimoto C<kimoto.yuki@gmail.com>

=head1 Copyright & License

Copyright 2023-2023 Yuki Kimoto, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

